import type { RouteSectionProps } from "@solidjs/router";

import Sidebar from "./components/sidebar";
import Player from "./components/player";
import { UserProvider } from "./contexts/user";
import { useBindings } from "./hooks/use-bindings";
import { cn } from "./lib/utils";
import { sizes } from "./lib/store";

import { store } from "./contexts/player";

export default function App({ children }: RouteSectionProps) {
	useBindings();

	return (
		<UserProvider>
			<div class="grid h-[100dvh] grid-rows-[1fr,auto]">
				<div
					class={cn(
						"grid h-full min-h-full grid-cols-[auto,1fr,auto] gap-2 bg-primary/90 p-2 pb-0 backdrop-blur",
					)}
				>
					<Sidebar />

					<main class="space overflow-y-auto bg-secondary">{children}</main>

					{store.queueOpen && (
						<div
							class="space bg-secondary"
							style={{ width: `${sizes.queue}px` }}
						>
							<h1 class="headline">Queue</h1>
						</div>
					)}
				</div>

				<Player />
			</div>
		</UserProvider>
	);
}
