import { As } from "@kobalte/core";
import { A } from "@solidjs/router";
import { createSignal, useContext } from "solid-js";

import * as Icons from "@/icons";
import {
	DropdownMenu,
	DropdownMenuContent,
	DropdownMenuItem,
	DropdownMenuSeparator,
	DropdownMenuTrigger,
} from "../ui/dropdown-menu";
import Playlists from "./playlists";
import { cn } from "@/lib/utils";
import { UserContext } from "@/contexts/user";
import { sizes } from "@/lib/store";

const links = [
	{
		href: "/",
		name: "Library",
		icon: Icons.FolderLibraryStroke,
	},
	{
		href: "/search",
		name: "Search",
		icon: Icons.FileSearchStroke,
	},
];

export default function Sidebar() {
	const [open, setOpen] = createSignal(false);
	const { user } = useContext(UserContext);

	return (
		<aside
			class="relative grid h-full w-full grid-rows-[max-content,1fr] flex-col gap-2 text-secondary"
			style={{ width: `${sizes.sidebar}px` }}
		>
			<div class="space flex items-center justify-between bg-secondary py-4">
				<A
					href={`/users/${user.id}`}
					class="flex h-full items-center gap-4 rounded-md px-3 transition-colors hover:bg-tertiary"
				>
					<div class="flex size-8 items-center justify-center rounded-full bg-tertiary text-sm font-bold text-secondary">
						{user.initials}
					</div>
					<span class="text-primary">{user.name}</span>
				</A>

				<DropdownMenu placement="bottom-end" onOpenChange={setOpen}>
					<DropdownMenuTrigger class="transition-colors hover:text-primary">
						<Icons.ArrowDown01Stroke
							class={cn("size-6 transition-transform", {
								"rotate-180 transform-gpu": open(),
							})}
						/>
					</DropdownMenuTrigger>

					<DropdownMenuContent>
						<DropdownMenuItem asChild>
							<As component={A} href="/users/asd">
								Profile
							</As>
						</DropdownMenuItem>
						<DropdownMenuItem asChild>
							<As component={A} href="/settings">
								Settings
							</As>
						</DropdownMenuItem>
						<DropdownMenuSeparator />
						<DropdownMenuItem
							class="text-red-400"
							onClick={() => alert("Would logout")}
						>
							Logout
						</DropdownMenuItem>
					</DropdownMenuContent>
				</DropdownMenu>
			</div>

			<div class="space h-100 flex flex-col gap-8 bg-secondary">
				<nav>
					{links.map((link) => (
						<A
							href={link.href}
							activeClass="bg-tertiary text-accent"
							class="mb-2 flex h-10 items-center gap-4 rounded-md px-4 transition-colors hover:bg-tertiary"
							end
						>
							<link.icon class="size-5" />
							<span class="text-primary">{link.name}</span>
						</A>
					))}
				</nav>

				<nav>
					<header class="mb-2 flex items-center justify-between">
						<h4 class="text-sm font-light uppercase tracking-widest text-secondary">
							Playlists
						</h4>
						<button>
							<Icons.PlusSignStroke size={20} />
						</button>
					</header>

					<Playlists />
				</nav>
			</div>
		</aside>
	);
}
