import { A } from "@solidjs/router";
import { For, Show, createResource } from "solid-js";

import * as Icons from "@/icons";
import { getPlaylists } from "@/lib/playlists";

export default function Playlists() {
	const [playlists] = createResource(getPlaylists);

	return (
		<Show when={!playlists.loading} fallback={<p>Loading...</p>}>
			<For each={playlists.latest}>
				{(playlist) => {
					const Icon =
						playlist.playlist_type === "folder"
							? Icons.Folder01Stroke
							: Icons.Playlist03Stroke;

					return (
						<A
							href={`/${playlist.playlist_type}s/${playlist.id}`}
							activeClass="bg-tertiary text-accent"
							class="mb-2 flex h-10 items-center gap-4 rounded-md px-4 transition-colors hover:bg-tertiary"
							end
						>
							<Icon class="size-5" />
							<span class="text-primary">{playlist.name}</span>
						</A>
					);
				}}
			</For>
		</Show>
	);
}
