import { createStore } from "solid-js/store";

import player from "@/lib/player";
import type { Track } from "@/types/track";

interface PlayerStore {
	playing: boolean;
	progress: number;
	duration: number;

	muted: boolean;
	volume: number;

	track: Track;

	queueOpen: boolean;

	shuffle: boolean;
	repeat: "none" | "one" | "all";
}

const [store, setStore] = createStore<PlayerStore>({
	playing: false,
	progress: 0,
	duration: 0,

	muted: false,
	volume: 0.5,

	track: player.getTrack(),

	queueOpen: false,

	shuffle: false,
	repeat: "none",
});

const audio = player.getAudio();

audio.addEventListener("play", () =>
	setStore((store) => ({ ...store, playing: true })),
);

audio.addEventListener("pause", () =>
	setStore((store) => ({ ...store, playing: false })),
);

audio.addEventListener("ended", () =>
	setStore((store) => ({ ...store, playing: false })),
);

audio.addEventListener("timeupdate", () => {
	setStore((store) => ({
		...store,
		progress: Math.floor(audio.currentTime),
		duration: Math.floor(audio.duration),
	}));
});

audio.addEventListener("volumechange", () => {
	setStore((store) => ({
		...store,
		muted: audio.muted,
		volume: audio.volume,
	}));
});

player.on("track", (track) => {
	setStore((store) => ({
		...store,
		track,
		progress: 0,
	}));
});

export { store, setStore };
