/* @refresh reload */
import { Route, Router } from "@solidjs/router";
import { lazy } from "solid-js";
import { render } from "solid-js/web";

import "./index.css";

import App from "./App";

const Library = lazy(() => import("./routes/library"));
const Search = lazy(() => import("./routes/search"));
const Artist = lazy(() => import("./routes/artists/[id]"));
const Playlist = lazy(() => import("./routes/playlists/[id]"));
const User = lazy(() => import("./routes/users/[id]"));
const NotFound = lazy(() => import("./routes/not-found"));

const root = document.getElementById("root");

render(
	() => (
		<Router root={App}>
			<Route path="/" component={Library} />
			<Route path="/search" component={Search} />

			<Route path="/artists/:artistId" component={Artist} />

			<Route path="/playlists/:playlistId" component={Playlist} />

			<Route path="/users/:userId" component={User} />

			<Route path="*404" component={NotFound} />
		</Router>
	),
	root!,
);
