import { A } from "@solidjs/router";
import { For, createSignal } from "solid-js";

import * as Icons from "@/icons";

import { Track as TrackType } from "@/types/track";
import time, { parseDuration } from "@/lib/time";
import { cn } from "@/lib/utils";
import player from "@/lib/player";

interface TrackProps {
	track: TrackType;
}

export default function Track({ track }: TrackProps) {
	const [liked, setLiked] = createSignal(false);

	return (
		<div
			class="playlist-row mb-2 cursor-pointer text-secondary transition-colors hover:bg-tertiary"
			onDblClick={() => player.changeTrack(track)}
		>
			<div class="size-12 rounded-md border bg-tertiary" />
			<div class="flex flex-col">
				<span class="text-base text-primary">{track.title}</span>
				<span class="text-sm">
					<For each={track.artists}>
						{(artist, i) => (
							<>
								<A href={`/artists/${artist.id}`} class="hover:underline">
									{artist.name}
								</A>
								{i() < track.artists.length - 1 && ", "}
							</>
						)}
					</For>
				</span>
			</div>
			<span class="text-sm">None</span>
			<span class="hidden text-center text-sm md:block">
				{Intl.DateTimeFormat("en-US", { dateStyle: "medium" }).format(
					new Date(track.added_at),
				)}
			</span>
			<span class="text-center text-sm">
				{time.duration(parseDuration(track.duration_ms)).format("m:ss")}
			</span>
			<div>
				<button onClick={() => setLiked(!liked())} class="hover:text-accent">
					<Icons.FavouriteStroke
						class={cn(
							"size-6 transition-colors hover:scale-110 hover:fill-accent",
							{
								"fill-accent": liked(),
							},
						)}
					/>
				</button>
			</div>
		</div>
	);
}
